﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Imaging;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Timers;
using AKE_Common;

namespace TestPlugin
{
	[Serializable]
	public class CPUMonitorPlugin: IInteractivePlugin
	{

		public string Variable { get; set; }
		public byte[] Output { get; set; }
		public int Height { get; set; }
		public int Width { get; set; }
		public Guid TileId { get; set; }

		public event EventHandler OutputUpdated;

		private Timer _timer;
		private PerformanceCounter _cpuCounter;

		public void Start()
		{
			_cpuCounter = new PerformanceCounter("Processor", "% Processor Time", "_Total");
			_timer = new Timer(Int32.Parse(Variable));
			_timer.Elapsed += TimerOnElapsed;
			_timer.Start();
		}

		public void Stop()
		{
			_cpuCounter.Close();
			_timer.Stop();
		}


		public CPUMonitorPlugin()
		{
		}

		private void TimerOnElapsed(object sender, ElapsedEventArgs elapsedEventArgs)
		{
			_timer.Stop();

			float usage = _cpuCounter.NextValue();

			Bitmap bitmap = new Bitmap(Width, Height, PixelFormat.Format32bppArgb);
			Graphics gfx = Graphics.FromImage(bitmap);
			gfx.FillRectangle(new SolidBrush(Color.Black), new Rectangle(0, 0, Width, Height));
			Color color = Color.FromArgb((int)(255 * (usage / 100)), (int)(255 * (1 - (usage / 100))), 0);
			gfx.FillRectangle(new SolidBrush(color), new Rectangle(0, Height - (int)((float)Height * (usage / 100)), Width, Height));
			gfx.DrawString("CPU\r\n" + ((int)usage).ToString() + "%", new Font(FontFamily.GenericSansSerif, 20, FontStyle.Regular), new SolidBrush(Color.Blue), new RectangleF(0, 0, Width, Height), new StringFormat() {Alignment = StringAlignment.Center, LineAlignment = StringAlignment.Center});
			gfx.Flush();
			bitmap.MakeTransparent(Color.Black);
			MemoryStream stream = new MemoryStream();
			bitmap.Save(stream, ImageFormat.Png);
			stream.Seek(0, 0);

			byte[] output = new byte[stream.Length];
			stream.Read(output, 0, (int)stream.Length);

			Output = output;
			OutputUpdated?.Invoke(this, new EventArgs());

			_timer.Start();
		}


		public void Run()
		{
			// no actions
		}

	}
}
